parse_from_reader

Function parse_from_reader 

pub fn parse_from_reader<R>(reader: R) -> Result<Axml, AxmlError>
where R: Read,
Parses the AXML from a generic reader

This is a more generic version of parse_from_string. This function will read and attempt to parse AXML from any type that implements the Read trait.